@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 my $test = Test::Builder->new;
 
@@ -44,6 +44,12 @@ sub tidyall_ok {
         @files = $ct->find_matched_files;
     }
 
+    unless (@files) {
+        $test->plan(1);
+        $test->ok( 1, 'found no matching files for tidyall_ok' );
+        return;
+    }
+
     $test->plan( tests => scalar(@files) );
     foreach my $file (@files) {
         my $desc   = $ct->_small_path($file);
@@ -86,7 +92,7 @@ tidyall
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
