@@ -1,7 +1,7 @@
 package Test::Code::TidyAll::Basic;
 
 use Cwd qw(realpath);
-use Code::TidyAll::Util qw(dirname mkpath pushd tempdir_simple);
+use Code::TidyAll::Util qw(mkpath pushd tempdir_simple);
 use Code::TidyAll;
 use Capture::Tiny qw(capture capture_stdout capture_merged);
 use File::Find qw(find);
@@ -18,52 +18,6 @@ my %AToZ       = ( test_plugin('AToZ')       => { select => '**/*.txt' } );
 
 my $cli_conf;
 
-sub create_dir {
-    my ( $self, $files ) = @_;
-
-    my $root_dir = tempdir_simple();
-    while ( my ( $path, $content ) = each(%$files) ) {
-        my $full_path = "$root_dir/$path";
-        mkpath( dirname($full_path), 0, 0775 );
-        write_file( $full_path, $content );
-    }
-    return realpath($root_dir);
-}
-
-sub tidy {
-    my ( $self, %params ) = @_;
-    my $desc = $params{desc};
-    if ( !defined($desc) ) {
-        ($desc) = ( ( caller(1) )[3] =~ /([^:]+$)/ );
-    }
-
-    my $root_dir = $self->create_dir( $params{source} );
-
-    my $options = $params{options} || {};
-    my $ct = Code::TidyAll->new(
-        plugins  => $params{plugins},
-        root_dir => $root_dir,
-        %$options
-    );
-
-    my @results;
-    my $output = capture_stdout { @results = $ct->process_all() };
-    my $error_count = grep { $_->error } @results;
-    if ( $params{errors} ) {
-        like( $output, $params{errors}, "$desc - errors" );
-        ok( $error_count > 0, "$desc - error_count > 0" );
-    }
-    else {
-        is( $error_count, 0, "$desc - error_count == 0" );
-    }
-    while ( my ( $path, $content ) = each( %{ $params{dest} } ) ) {
-        is( read_file("$root_dir/$path"), $content, "$desc - $path content" );
-    }
-    if ( my $like_output = $params{like_output} ) {
-        like( $output, $like_output, "$desc - output" );
-    }
-}
-
 sub test_basic : Tests {
     my $self = shift;
 
@@ -137,7 +91,11 @@ sub test_plugin_order_and_atomicity : Tests {
         (
             %ReverseFoo,
             test_plugin("UpperText $_")  => { select => '**/*.txt' },
-            test_plugin("CheckUpper $_") => { select => '**/*.txt' }
+            test_plugin("CheckUpper $_") => { select => '**/*.txt' },
+
+            # note without the weight here this would run first, and the
+            # letters in the photetic words themselves would be reversed
+            test_plugin("AlwaysPhonetic") => { select => '**/*.txt', weight => 51 }
             )
     } ( 1 .. 3 );
     my $output = capture_stdout {
@@ -145,7 +103,7 @@ sub test_plugin_order_and_atomicity : Tests {
             plugins => {@plugins},
             options => { verbose => 1 },
             source  => { "foo.txt" => "abc" },
-            dest    => { "foo.txt" => "CBA" },
+            dest    => { "foo.txt" => "CHARLIE-BRAVO-ALFA" },
             like_output =>
                 qr/.*ReverseFoo, .*UpperText 1, .*UpperText 2, .*UpperText 3, .*CheckUpper 1, .*CheckUpper 2, .*CheckUpper 3/
         );
